From: Pedro Alves <palves@redhat.com>
Cc: gdb-patches@sourceware.org, Jan Kratochvil <jan.kratochvil@redhat.com>
Subject: Re: [patch 2/2] Fix watchpoints for multi-inferior #2
Date: Fri, 16 Mar 2012 20:11:00 -0000 [thread overview]
Message-ID: <4F639E4F.1060803@redhat.com> (raw)
In-Reply-To: <4F205F3C.7090406@redhat.com>
Here's what I'm applying. I've added comments inspired on your follow-up patch.
This makes watchpoint-multi.exp pass cleanly with the extended-remote
board, on x86_64 Fedora 16.
gdb/gdbserver/
2012-03-16 Pedro Alves <palves@redhat.com>
Jan Kratochvil <jan.kratochvil@redhat.com>
* server.c (cont_thread, general_thread): Add describing comments.
(start_inferior): Clear `cont_thread'.
(handle_v_cont): Don't set `cont_thread' if resuming all threads
of a process.
---
gdb/gdbserver/server.c | 24 ++++++++++++++++++++++--
1 files changed, 22 insertions(+), 2 deletions(-)
diff --git a/gdb/gdbserver/server.c b/gdb/gdbserver/server.c
index 3c97dbd..a4e9e57 100644
--- a/gdb/gdbserver/server.c
+++ b/gdb/gdbserver/server.c
@@ -30,7 +30,19 @@
#include <sys/wait.h>
#endif
+/* The thread set with an `Hc' packet. `Hc' is deprecated in favor of
+ `vCont'. Note the multi-process extensions made `vCont' a
+ requirement, so `Hc pPID.TID' is pretty much undefined. So
+ CONT_THREAD can be null_ptid for no `Hc' thread, minus_one_ptid for
+ resuming all threads of the process (again, `Hc' isn't used for
+ multi-process), or a specific thread ptid_t.
+
+ We also set this when handling a single-thread `vCont' resume, as
+ some places in the backends check it to know when (and for which
+ thread) single-thread scheduler-locking is in effect. */
ptid_t cont_thread;
+
+/* The thread set with an `Hg' packet. */
ptid_t general_thread;
int server_waiting;
@@ -262,6 +274,10 @@ start_inferior (char **argv)
signal (SIGTTIN, SIG_DFL);
#endif
+ /* Clear this so the backend doesn't get confused, thinking
+ CONT_THREAD died, and it needs to resume all threads. */
+ cont_thread = null_ptid;
+
signal_pid = create_inferior (new_argv[0], new_argv);
/* FIXME: we don't actually know at this point that the create
@@ -1962,9 +1978,13 @@ handle_v_cont (char *own_buf)
if (i < n)
resume_info[i] = default_action;
- /* Still used in occasional places in the backend. */
+ /* `cont_thread' is still used in occasional places in the backend,
+ to implement single-thread scheduler-locking. Doesn't make sense
+ to set it if we see a stop request, or any form of wildcard
+ vCont. */
if (n == 1
- && !ptid_equal (resume_info[0].thread, minus_one_ptid)
+ && !(ptid_equal (resume_info[0].thread, minus_one_ptid)
+ || ptid_get_lwp (resume_info[0].thread) == -1)
&& resume_info[0].kind != resume_stop)
cont_thread = resume_info[0].thread;
else
next prev parent reply other threads:[~2012-03-16 20:11 UTC|newest]
Thread overview: 14+ messages / expand[flat|nested] mbox.gz Atom feed top
2012-01-02 16:47 [patch 2/2] Fix watchpoints for multi-inferior Jan Kratochvil
2012-01-02 19:14 ` Pedro Alves
2012-01-20 21:34 ` [patch 2/2] Fix watchpoints for multi-inferior #2 Jan Kratochvil
2012-01-24 13:40 ` Pedro Alves
2012-01-24 14:20 ` [commit] " Jan Kratochvil
2012-01-25 15:57 ` Jan Kratochvil
2012-01-25 17:54 ` Pedro Alves
2012-01-25 18:22 ` Pedro Alves
2012-01-25 20:08 ` Pedro Alves
2012-01-26 21:56 ` [patch] protocol doc vs. gdbserver on H and pPID.-1 etc. [Re: [patch 2/2] Fix watchpoints for multi-inferior #2] Jan Kratochvil
2012-01-27 11:53 ` Pedro Alves
2012-01-27 12:02 ` Pedro Alves
2012-03-16 20:11 ` Pedro Alves [this message]
2012-03-16 20:14 ` [patch 2/2] Fix watchpoints for multi-inferior #2 Jan Kratochvil
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=4F639E4F.1060803@redhat.com \
--to=palves@redhat.com \
--cc=gdb-patches@sourceware.org \
--cc=jan.kratochvil@redhat.com \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox